# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["SessionCopyResponse"]


class SessionCopyResponse(BaseModel):
    text: Optional[str] = None
    """The text that was copied"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Mapping, cast

import httpx

from ..types import extension_upload_params
from .._types import Body, Query, Headers, NotGiven, FileTypes, not_given
from .._utils import extract_files, maybe_transform, deepcopy_minimal, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.extension_list_response import ExtensionListResponse
from ..types.extension_delete_response import ExtensionDeleteResponse
from ..types.extension_upload_response import ExtensionUploadResponse
from ..types.extension_retrieve_response import ExtensionRetrieveResponse

__all__ = ["ExtensionsResource", "AsyncExtensionsResource"]


class ExtensionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ExtensionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#accessing-raw-response-data-eg-headers
        """
        return ExtensionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ExtensionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#with_streaming_response
        """
        return ExtensionsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExtensionRetrieveResponse:
        """
        Get details of a specific extension by its ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v1/extensions/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExtensionRetrieveResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExtensionListResponse:
        """Get all extensions for the authenticated user"""
        return self._get(
            "/v1/extensions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExtensionListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExtensionDeleteResponse:
        """
        Delete an extension and remove it from storage

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/v1/extensions/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExtensionDeleteResponse,
        )

    def upload(
        self,
        *,
        file: FileTypes,
        name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExtensionUploadResponse:
        """Upload a new browser extension as a ZIP file.

        The extension will be validated
        and stored for use in browser sessions.

        Args:
          file: ZIP file containing the browser extension

          name: User-friendly name for the extension (1-255 characters)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        body = deepcopy_minimal(
            {
                "file": file,
                "name": name,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return self._post(
            "/v1/extensions",
            body=maybe_transform(body, extension_upload_params.ExtensionUploadParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExtensionUploadResponse,
        )


class AsyncExtensionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncExtensionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#accessing-raw-response-data-eg-headers
        """
        return AsyncExtensionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncExtensionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#with_streaming_response
        """
        return AsyncExtensionsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExtensionRetrieveResponse:
        """
        Get details of a specific extension by its ID

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v1/extensions/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExtensionRetrieveResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExtensionListResponse:
        """Get all extensions for the authenticated user"""
        return await self._get(
            "/v1/extensions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExtensionListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExtensionDeleteResponse:
        """
        Delete an extension and remove it from storage

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/v1/extensions/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExtensionDeleteResponse,
        )

    async def upload(
        self,
        *,
        file: FileTypes,
        name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ExtensionUploadResponse:
        """Upload a new browser extension as a ZIP file.

        The extension will be validated
        and stored for use in browser sessions.

        Args:
          file: ZIP file containing the browser extension

          name: User-friendly name for the extension (1-255 characters)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        body = deepcopy_minimal(
            {
                "file": file,
                "name": name,
            }
        )
        files = extract_files(cast(Mapping[str, object], body), paths=[["file"]])
        # It should be noted that the actual Content-Type header that will be
        # sent to the server will contain a `boundary` parameter, e.g.
        # multipart/form-data; boundary=---abc--
        extra_headers = {"Content-Type": "multipart/form-data", **(extra_headers or {})}
        return await self._post(
            "/v1/extensions",
            body=await async_maybe_transform(body, extension_upload_params.ExtensionUploadParams),
            files=files,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ExtensionUploadResponse,
        )


class ExtensionsResourceWithRawResponse:
    def __init__(self, extensions: ExtensionsResource) -> None:
        self._extensions = extensions

        self.retrieve = to_raw_response_wrapper(
            extensions.retrieve,
        )
        self.list = to_raw_response_wrapper(
            extensions.list,
        )
        self.delete = to_raw_response_wrapper(
            extensions.delete,
        )
        self.upload = to_raw_response_wrapper(
            extensions.upload,
        )


class AsyncExtensionsResourceWithRawResponse:
    def __init__(self, extensions: AsyncExtensionsResource) -> None:
        self._extensions = extensions

        self.retrieve = async_to_raw_response_wrapper(
            extensions.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            extensions.list,
        )
        self.delete = async_to_raw_response_wrapper(
            extensions.delete,
        )
        self.upload = async_to_raw_response_wrapper(
            extensions.upload,
        )


class ExtensionsResourceWithStreamingResponse:
    def __init__(self, extensions: ExtensionsResource) -> None:
        self._extensions = extensions

        self.retrieve = to_streamed_response_wrapper(
            extensions.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            extensions.list,
        )
        self.delete = to_streamed_response_wrapper(
            extensions.delete,
        )
        self.upload = to_streamed_response_wrapper(
            extensions.upload,
        )


class AsyncExtensionsResourceWithStreamingResponse:
    def __init__(self, extensions: AsyncExtensionsResource) -> None:
        self._extensions = extensions

        self.retrieve = async_to_streamed_response_wrapper(
            extensions.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            extensions.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            extensions.delete,
        )
        self.upload = async_to_streamed_response_wrapper(
            extensions.upload,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["BatchSessionRetrieveResponse", "Data", "DataProgress", "DataSession"]


class DataProgress(BaseModel):
    current_phase: Optional[Literal["queued", "provisioning", "configuring", "ready"]] = None
    """Current processing phase"""

    percentage: Optional[float] = None
    """Completion percentage (0-100)"""


class DataSession(BaseModel):
    cdp_url: Optional[str] = None
    """CDP websocket connection URL (if session is ready)"""

    completed_at: Optional[datetime] = None
    """Timestamp when session creation completed"""

    error: Optional[str] = None
    """Error message if session creation failed"""

    item_index: Optional[int] = None
    """Index of this session within the batch (0-based)"""

    live_view_url: Optional[str] = None
    """Live view URL for the session (if session is ready)"""

    metadata: Optional[Dict[str, object]] = None
    """Session-specific metadata"""

    retry_count: Optional[int] = None
    """Number of times this session creation has been retried"""

    session_id: Optional[str] = None
    """Unique identifier for the browser session (if created successfully)"""

    started_at: Optional[datetime] = None
    """Timestamp when session creation started"""

    status: Optional[Literal["pending", "processing", "completed", "failed"]] = None
    """Current status of this individual session"""


class Data(BaseModel):
    actual_completion_time: Optional[datetime] = None
    """Timestamp when the batch completed (if completed)"""

    batch_id: Optional[str] = None
    """Unique identifier for the batch"""

    completed_requests: Optional[int] = None
    """Number of sessions successfully created"""

    created_at: Optional[datetime] = None
    """Timestamp when the batch was created"""

    error: Optional[str] = None
    """Error message if batch failed"""

    failed_requests: Optional[int] = None
    """Number of sessions that failed to create"""

    pending_requests: Optional[int] = None
    """Number of sessions waiting to be processed"""

    processing_requests: Optional[int] = None
    """Number of sessions currently being processed"""

    progress: Optional[DataProgress] = None

    sessions: Optional[List[DataSession]] = None
    """Array of individual session details"""

    status: Optional[Literal["pending", "processing", "completed", "failed"]] = None
    """Current status of the batch"""

    total_requests: Optional[int] = None
    """Total number of sessions requested"""


class BatchSessionRetrieveResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from anchorbrowser import Anchorbrowser, AsyncAnchorbrowser
from anchorbrowser.types import TaskListResponse, TaskCreateResponse
from anchorbrowser.types.task import RunExecuteResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTask:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Anchorbrowser) -> None:
        task = client.task.create(
            language="typescript",
            name="web-scraper",
        )
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Anchorbrowser) -> None:
        task = client.task.create(
            language="typescript",
            name="web-scraper",
            browser_configuration={
                "initial_url": "https://example.com",
                "live_view": {"read_only": True},
                "proxy": {
                    "active": True,
                    "city": "city",
                    "country_code": "af",
                    "region": "region",
                    "type": "anchor_proxy",
                },
                "recording": {"active": True},
                "timeout": {
                    "idle_timeout": 0,
                    "max_duration": 0,
                },
            },
            code="Y29uc3QgYW5jaG9yID0gcmVxdWlyZSgnYW5jaG9yYnJvd3NlcicpOwoKYXN5bmMgZnVuY3Rpb24gcnVuKCkgewogIGNvbnN0IHNlc3Npb24gPSBhd2FpdCBhbmNob3IuY3JlYXRlU2Vzc2lvbigpOwogIGF3YWl0IHNlc3Npb24uZ29UbygnaHR0cHM6Ly9leGFtcGxlLmNvbScpOwogIGNvbnN0IHRpdGxlID0gYXdhaXQgc2Vzc2lvbi5nZXRUaXRsZSgpOwogIGNvbnNvbGUubG9nKHRpdGxlKTsKICBhd2FpdCBzZXNzaW9uLmNsb3NlKCk7Cn0KcnVuKCk7",
            description="A task to scrape product information from e-commerce sites",
        )
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Anchorbrowser) -> None:
        response = client.task.with_raw_response.create(
            language="typescript",
            name="web-scraper",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = response.parse()
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Anchorbrowser) -> None:
        with client.task.with_streaming_response.create(
            language="typescript",
            name="web-scraper",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = response.parse()
            assert_matches_type(TaskCreateResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Anchorbrowser) -> None:
        task = client.task.list()
        assert_matches_type(TaskListResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Anchorbrowser) -> None:
        task = client.task.list(
            limit="469",
            page="469",
        )
        assert_matches_type(TaskListResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Anchorbrowser) -> None:
        response = client.task.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = response.parse()
        assert_matches_type(TaskListResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Anchorbrowser) -> None:
        with client.task.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = response.parse()
            assert_matches_type(TaskListResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_run(self, client: Anchorbrowser) -> None:
        run = client.task.run(
            task_id="550e8400-e29b-41d4-a716-446655440000",
        )
        assert_matches_type(RunExecuteResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_run_with_all_params(self, client: Anchorbrowser) -> None:
        run = client.task.run(
            task_id="550e8400-e29b-41d4-a716-446655440000",
            inputs={
                "ANCHOR_TARGET_URL": "https://example.com",
                "ANCHOR_MAX_PAGES": "10",
            },
            override_browser_configuration={
                "initial_url": "https://example.com",
                "live_view": {"read_only": True},
                "proxy": {
                    "active": True,
                    "city": "city",
                    "country_code": "af",
                    "region": "region",
                    "type": "anchor_proxy",
                },
                "recording": {"active": True},
                "timeout": {
                    "idle_timeout": 0,
                    "max_duration": 0,
                },
            },
            session_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            task_session_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            version="1",
        )
        assert_matches_type(RunExecuteResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_run(self, client: Anchorbrowser) -> None:
        response = client.task.with_raw_response.run(
            task_id="550e8400-e29b-41d4-a716-446655440000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunExecuteResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_run(self, client: Anchorbrowser) -> None:
        with client.task.with_streaming_response.run(
            task_id="550e8400-e29b-41d4-a716-446655440000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunExecuteResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncTask:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncAnchorbrowser) -> None:
        task = await async_client.task.create(
            language="typescript",
            name="web-scraper",
        )
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncAnchorbrowser) -> None:
        task = await async_client.task.create(
            language="typescript",
            name="web-scraper",
            browser_configuration={
                "initial_url": "https://example.com",
                "live_view": {"read_only": True},
                "proxy": {
                    "active": True,
                    "city": "city",
                    "country_code": "af",
                    "region": "region",
                    "type": "anchor_proxy",
                },
                "recording": {"active": True},
                "timeout": {
                    "idle_timeout": 0,
                    "max_duration": 0,
                },
            },
            code="Y29uc3QgYW5jaG9yID0gcmVxdWlyZSgnYW5jaG9yYnJvd3NlcicpOwoKYXN5bmMgZnVuY3Rpb24gcnVuKCkgewogIGNvbnN0IHNlc3Npb24gPSBhd2FpdCBhbmNob3IuY3JlYXRlU2Vzc2lvbigpOwogIGF3YWl0IHNlc3Npb24uZ29UbygnaHR0cHM6Ly9leGFtcGxlLmNvbScpOwogIGNvbnN0IHRpdGxlID0gYXdhaXQgc2Vzc2lvbi5nZXRUaXRsZSgpOwogIGNvbnNvbGUubG9nKHRpdGxlKTsKICBhd2FpdCBzZXNzaW9uLmNsb3NlKCk7Cn0KcnVuKCk7",
            description="A task to scrape product information from e-commerce sites",
        )
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.task.with_raw_response.create(
            language="typescript",
            name="web-scraper",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = await response.parse()
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.task.with_streaming_response.create(
            language="typescript",
            name="web-scraper",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = await response.parse()
            assert_matches_type(TaskCreateResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncAnchorbrowser) -> None:
        task = await async_client.task.list()
        assert_matches_type(TaskListResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncAnchorbrowser) -> None:
        task = await async_client.task.list(
            limit="469",
            page="469",
        )
        assert_matches_type(TaskListResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.task.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = await response.parse()
        assert_matches_type(TaskListResponse, task, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.task.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = await response.parse()
            assert_matches_type(TaskListResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_run(self, async_client: AsyncAnchorbrowser) -> None:
        run = await async_client.task.run(
            task_id="550e8400-e29b-41d4-a716-446655440000",
        )
        assert_matches_type(RunExecuteResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_run_with_all_params(self, async_client: AsyncAnchorbrowser) -> None:
        run = await async_client.task.run(
            task_id="550e8400-e29b-41d4-a716-446655440000",
            inputs={
                "ANCHOR_TARGET_URL": "https://example.com",
                "ANCHOR_MAX_PAGES": "10",
            },
            override_browser_configuration={
                "initial_url": "https://example.com",
                "live_view": {"read_only": True},
                "proxy": {
                    "active": True,
                    "city": "city",
                    "country_code": "af",
                    "region": "region",
                    "type": "anchor_proxy",
                },
                "recording": {"active": True},
                "timeout": {
                    "idle_timeout": 0,
                    "max_duration": 0,
                },
            },
            session_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            task_session_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            version="1",
        )
        assert_matches_type(RunExecuteResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_run(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.task.with_raw_response.run(
            task_id="550e8400-e29b-41d4-a716-446655440000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunExecuteResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_run(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.task.with_streaming_response.run(
            task_id="550e8400-e29b-41d4-a716-446655440000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunExecuteResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from anchorbrowser import Anchorbrowser, AsyncAnchorbrowser
from anchorbrowser.types import EventWaitForResponse
from anchorbrowser.types.shared import SuccessResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEvents:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_signal(self, client: Anchorbrowser) -> None:
        event = client.events.signal(
            event_name="event_name",
            data={
                "message": "bar",
                "result": "bar",
                "timestamp": "bar",
            },
        )
        assert_matches_type(SuccessResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_signal(self, client: Anchorbrowser) -> None:
        response = client.events.with_raw_response.signal(
            event_name="event_name",
            data={
                "message": "bar",
                "result": "bar",
                "timestamp": "bar",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        event = response.parse()
        assert_matches_type(SuccessResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_signal(self, client: Anchorbrowser) -> None:
        with client.events.with_streaming_response.signal(
            event_name="event_name",
            data={
                "message": "bar",
                "result": "bar",
                "timestamp": "bar",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            event = response.parse()
            assert_matches_type(SuccessResponse, event, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_signal(self, client: Anchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `event_name` but received ''"):
            client.events.with_raw_response.signal(
                event_name="",
                data={
                    "message": "bar",
                    "result": "bar",
                    "timestamp": "bar",
                },
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_wait_for(self, client: Anchorbrowser) -> None:
        event = client.events.wait_for(
            event_name="event_name",
        )
        assert_matches_type(EventWaitForResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_wait_for_with_all_params(self, client: Anchorbrowser) -> None:
        event = client.events.wait_for(
            event_name="event_name",
            timeout_ms=0,
        )
        assert_matches_type(EventWaitForResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_wait_for(self, client: Anchorbrowser) -> None:
        response = client.events.with_raw_response.wait_for(
            event_name="event_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        event = response.parse()
        assert_matches_type(EventWaitForResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_wait_for(self, client: Anchorbrowser) -> None:
        with client.events.with_streaming_response.wait_for(
            event_name="event_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            event = response.parse()
            assert_matches_type(EventWaitForResponse, event, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_wait_for(self, client: Anchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `event_name` but received ''"):
            client.events.with_raw_response.wait_for(
                event_name="",
            )


class TestAsyncEvents:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_signal(self, async_client: AsyncAnchorbrowser) -> None:
        event = await async_client.events.signal(
            event_name="event_name",
            data={
                "message": "bar",
                "result": "bar",
                "timestamp": "bar",
            },
        )
        assert_matches_type(SuccessResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_signal(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.events.with_raw_response.signal(
            event_name="event_name",
            data={
                "message": "bar",
                "result": "bar",
                "timestamp": "bar",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        event = await response.parse()
        assert_matches_type(SuccessResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_signal(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.events.with_streaming_response.signal(
            event_name="event_name",
            data={
                "message": "bar",
                "result": "bar",
                "timestamp": "bar",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            event = await response.parse()
            assert_matches_type(SuccessResponse, event, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_signal(self, async_client: AsyncAnchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `event_name` but received ''"):
            await async_client.events.with_raw_response.signal(
                event_name="",
                data={
                    "message": "bar",
                    "result": "bar",
                    "timestamp": "bar",
                },
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_wait_for(self, async_client: AsyncAnchorbrowser) -> None:
        event = await async_client.events.wait_for(
            event_name="event_name",
        )
        assert_matches_type(EventWaitForResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_wait_for_with_all_params(self, async_client: AsyncAnchorbrowser) -> None:
        event = await async_client.events.wait_for(
            event_name="event_name",
            timeout_ms=0,
        )
        assert_matches_type(EventWaitForResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_wait_for(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.events.with_raw_response.wait_for(
            event_name="event_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        event = await response.parse()
        assert_matches_type(EventWaitForResponse, event, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_wait_for(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.events.with_streaming_response.wait_for(
            event_name="event_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            event = await response.parse()
            assert_matches_type(EventWaitForResponse, event, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_wait_for(self, async_client: AsyncAnchorbrowser) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `event_name` but received ''"):
            await async_client.events.with_raw_response.wait_for(
                event_name="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["SessionScrollResponse"]


class SessionScrollResponse(BaseModel):
    status: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .run_execute_params import RunExecuteParams as RunExecuteParams
from .run_execute_response import RunExecuteResponse as RunExecuteResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict

import httpx

from ..types import batch_session_create_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.batch_session_create_response import BatchSessionCreateResponse
from ..types.batch_session_retrieve_response import BatchSessionRetrieveResponse

__all__ = ["BatchSessionsResource", "AsyncBatchSessionsResource"]


class BatchSessionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> BatchSessionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#accessing-raw-response-data-eg-headers
        """
        return BatchSessionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> BatchSessionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#with_streaming_response
        """
        return BatchSessionsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        count: int,
        configuration: batch_session_create_params.Configuration | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BatchSessionCreateResponse:
        """Creates multiple browser sessions in a single batch operation.

        This endpoint
        allows you to create up to 5,000 browser sessions simultaneously with the same
        configuration.

        The batch will be processed asynchronously, and you can monitor progress using
        the batch status endpoint.

        Args:
          count: Number of sessions to create in the batch (1-1000)

          configuration: Configuration that applies to all sessions in the batch

          metadata: Optional batch-level metadata for identification and organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/batch-sessions",
            body=maybe_transform(
                {
                    "count": count,
                    "configuration": configuration,
                    "metadata": metadata,
                },
                batch_session_create_params.BatchSessionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BatchSessionCreateResponse,
        )

    def retrieve(
        self,
        batch_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BatchSessionRetrieveResponse:
        """
        Retrieves detailed status information for a specific batch, including progress,
        individual session details, and any errors that occurred.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not batch_id:
            raise ValueError(f"Expected a non-empty value for `batch_id` but received {batch_id!r}")
        return self._get(
            f"/v1/batch-sessions/{batch_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BatchSessionRetrieveResponse,
        )


class AsyncBatchSessionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncBatchSessionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#accessing-raw-response-data-eg-headers
        """
        return AsyncBatchSessionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncBatchSessionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#with_streaming_response
        """
        return AsyncBatchSessionsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        count: int,
        configuration: batch_session_create_params.Configuration | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BatchSessionCreateResponse:
        """Creates multiple browser sessions in a single batch operation.

        This endpoint
        allows you to create up to 5,000 browser sessions simultaneously with the same
        configuration.

        The batch will be processed asynchronously, and you can monitor progress using
        the batch status endpoint.

        Args:
          count: Number of sessions to create in the batch (1-1000)

          configuration: Configuration that applies to all sessions in the batch

          metadata: Optional batch-level metadata for identification and organization

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/batch-sessions",
            body=await async_maybe_transform(
                {
                    "count": count,
                    "configuration": configuration,
                    "metadata": metadata,
                },
                batch_session_create_params.BatchSessionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BatchSessionCreateResponse,
        )

    async def retrieve(
        self,
        batch_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BatchSessionRetrieveResponse:
        """
        Retrieves detailed status information for a specific batch, including progress,
        individual session details, and any errors that occurred.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not batch_id:
            raise ValueError(f"Expected a non-empty value for `batch_id` but received {batch_id!r}")
        return await self._get(
            f"/v1/batch-sessions/{batch_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BatchSessionRetrieveResponse,
        )


class BatchSessionsResourceWithRawResponse:
    def __init__(self, batch_sessions: BatchSessionsResource) -> None:
        self._batch_sessions = batch_sessions

        self.create = to_raw_response_wrapper(
            batch_sessions.create,
        )
        self.retrieve = to_raw_response_wrapper(
            batch_sessions.retrieve,
        )


class AsyncBatchSessionsResourceWithRawResponse:
    def __init__(self, batch_sessions: AsyncBatchSessionsResource) -> None:
        self._batch_sessions = batch_sessions

        self.create = async_to_raw_response_wrapper(
            batch_sessions.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            batch_sessions.retrieve,
        )


class BatchSessionsResourceWithStreamingResponse:
    def __init__(self, batch_sessions: BatchSessionsResource) -> None:
        self._batch_sessions = batch_sessions

        self.create = to_streamed_response_wrapper(
            batch_sessions.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            batch_sessions.retrieve,
        )


class AsyncBatchSessionsResourceWithStreamingResponse:
    def __init__(self, batch_sessions: AsyncBatchSessionsResource) -> None:
        self._batch_sessions = batch_sessions

        self.create = async_to_streamed_response_wrapper(
            batch_sessions.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            batch_sessions.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from .._models import BaseModel

__all__ = ["EventWaitForResponse"]


class EventWaitForResponse(BaseModel):
    data: Optional[Dict[str, object]] = None
    """The event data that was signaled"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .shared.success_response import SuccessResponse

__all__ = ["ExtensionDeleteResponse"]


class ExtensionDeleteResponse(BaseModel):
    data: Optional[SuccessResponse] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["ClipboardGetResponse", "Data"]


class Data(BaseModel):
    text: Optional[str] = None
    """Text content of the clipboard"""


class ClipboardGetResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["TaskListParams"]


class TaskListParams(TypedDict, total=False):
    limit: str
    """Number of tasks per page"""

    page: str
    """Page number"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import httpx
import pytest
from respx import MockRouter

from tests.utils import assert_matches_type
from anchorbrowser import Anchorbrowser, AsyncAnchorbrowser
from anchorbrowser.types import (
    ToolPerformWebTaskResponse,
)
from anchorbrowser._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTools:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_fetch_webpage(self, client: Anchorbrowser) -> None:
        tool = client.tools.fetch_webpage()
        assert_matches_type(str, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_fetch_webpage_with_all_params(self, client: Anchorbrowser) -> None:
        tool = client.tools.fetch_webpage(
            session_id="sessionId",
            format="html",
            new_page=True,
            page_index=0,
            return_partial_on_timeout=True,
            url="url",
            wait=0,
        )
        assert_matches_type(str, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_fetch_webpage(self, client: Anchorbrowser) -> None:
        response = client.tools.with_raw_response.fetch_webpage()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tool = response.parse()
        assert_matches_type(str, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_fetch_webpage(self, client: Anchorbrowser) -> None:
        with client.tools.with_streaming_response.fetch_webpage() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tool = response.parse()
            assert_matches_type(str, tool, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_perform_web_task(self, client: Anchorbrowser) -> None:
        tool = client.tools.perform_web_task(
            prompt="prompt",
        )
        assert_matches_type(ToolPerformWebTaskResponse, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_perform_web_task_with_all_params(self, client: Anchorbrowser) -> None:
        tool = client.tools.perform_web_task(
            prompt="prompt",
            session_id="sessionId",
            agent="browser-use",
            detect_elements=True,
            highlight_elements=True,
            human_intervention=True,
            max_steps=0,
            model="model",
            output_schema={},
            provider="openai",
            secret_values={"foo": "string"},
            url="url",
        )
        assert_matches_type(ToolPerformWebTaskResponse, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_perform_web_task(self, client: Anchorbrowser) -> None:
        response = client.tools.with_raw_response.perform_web_task(
            prompt="prompt",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tool = response.parse()
        assert_matches_type(ToolPerformWebTaskResponse, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_perform_web_task(self, client: Anchorbrowser) -> None:
        with client.tools.with_streaming_response.perform_web_task(
            prompt="prompt",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tool = response.parse()
            assert_matches_type(ToolPerformWebTaskResponse, tool, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_screenshot_webpage(self, client: Anchorbrowser, respx_mock: MockRouter) -> None:
        respx_mock.post("/v1/tools/screenshot").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        tool = client.tools.screenshot_webpage()
        assert tool.is_closed
        assert tool.json() == {"foo": "bar"}
        assert cast(Any, tool.is_closed) is True
        assert isinstance(tool, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_method_screenshot_webpage_with_all_params(self, client: Anchorbrowser, respx_mock: MockRouter) -> None:
        respx_mock.post("/v1/tools/screenshot").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        tool = client.tools.screenshot_webpage(
            session_id="sessionId",
            capture_full_height=True,
            height=0,
            image_quality=0,
            s3_target_address="s3_target_address",
            scroll_all_content=True,
            url="url",
            wait=0,
            width=0,
        )
        assert tool.is_closed
        assert tool.json() == {"foo": "bar"}
        assert cast(Any, tool.is_closed) is True
        assert isinstance(tool, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_raw_response_screenshot_webpage(self, client: Anchorbrowser, respx_mock: MockRouter) -> None:
        respx_mock.post("/v1/tools/screenshot").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        tool = client.tools.with_raw_response.screenshot_webpage()

        assert tool.is_closed is True
        assert tool.http_request.headers.get("X-Stainless-Lang") == "python"
        assert tool.json() == {"foo": "bar"}
        assert isinstance(tool, BinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    def test_streaming_response_screenshot_webpage(self, client: Anchorbrowser, respx_mock: MockRouter) -> None:
        respx_mock.post("/v1/tools/screenshot").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        with client.tools.with_streaming_response.screenshot_webpage() as tool:
            assert not tool.is_closed
            assert tool.http_request.headers.get("X-Stainless-Lang") == "python"

            assert tool.json() == {"foo": "bar"}
            assert cast(Any, tool.is_closed) is True
            assert isinstance(tool, StreamedBinaryAPIResponse)

        assert cast(Any, tool.is_closed) is True


class TestAsyncTools:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_fetch_webpage(self, async_client: AsyncAnchorbrowser) -> None:
        tool = await async_client.tools.fetch_webpage()
        assert_matches_type(str, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_fetch_webpage_with_all_params(self, async_client: AsyncAnchorbrowser) -> None:
        tool = await async_client.tools.fetch_webpage(
            session_id="sessionId",
            format="html",
            new_page=True,
            page_index=0,
            return_partial_on_timeout=True,
            url="url",
            wait=0,
        )
        assert_matches_type(str, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_fetch_webpage(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.tools.with_raw_response.fetch_webpage()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tool = await response.parse()
        assert_matches_type(str, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_fetch_webpage(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.tools.with_streaming_response.fetch_webpage() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tool = await response.parse()
            assert_matches_type(str, tool, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_perform_web_task(self, async_client: AsyncAnchorbrowser) -> None:
        tool = await async_client.tools.perform_web_task(
            prompt="prompt",
        )
        assert_matches_type(ToolPerformWebTaskResponse, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_perform_web_task_with_all_params(self, async_client: AsyncAnchorbrowser) -> None:
        tool = await async_client.tools.perform_web_task(
            prompt="prompt",
            session_id="sessionId",
            agent="browser-use",
            detect_elements=True,
            highlight_elements=True,
            human_intervention=True,
            max_steps=0,
            model="model",
            output_schema={},
            provider="openai",
            secret_values={"foo": "string"},
            url="url",
        )
        assert_matches_type(ToolPerformWebTaskResponse, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_perform_web_task(self, async_client: AsyncAnchorbrowser) -> None:
        response = await async_client.tools.with_raw_response.perform_web_task(
            prompt="prompt",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tool = await response.parse()
        assert_matches_type(ToolPerformWebTaskResponse, tool, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_perform_web_task(self, async_client: AsyncAnchorbrowser) -> None:
        async with async_client.tools.with_streaming_response.perform_web_task(
            prompt="prompt",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tool = await response.parse()
            assert_matches_type(ToolPerformWebTaskResponse, tool, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_screenshot_webpage(self, async_client: AsyncAnchorbrowser, respx_mock: MockRouter) -> None:
        respx_mock.post("/v1/tools/screenshot").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        tool = await async_client.tools.screenshot_webpage()
        assert tool.is_closed
        assert await tool.json() == {"foo": "bar"}
        assert cast(Any, tool.is_closed) is True
        assert isinstance(tool, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_method_screenshot_webpage_with_all_params(
        self, async_client: AsyncAnchorbrowser, respx_mock: MockRouter
    ) -> None:
        respx_mock.post("/v1/tools/screenshot").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        tool = await async_client.tools.screenshot_webpage(
            session_id="sessionId",
            capture_full_height=True,
            height=0,
            image_quality=0,
            s3_target_address="s3_target_address",
            scroll_all_content=True,
            url="url",
            wait=0,
            width=0,
        )
        assert tool.is_closed
        assert await tool.json() == {"foo": "bar"}
        assert cast(Any, tool.is_closed) is True
        assert isinstance(tool, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_raw_response_screenshot_webpage(
        self, async_client: AsyncAnchorbrowser, respx_mock: MockRouter
    ) -> None:
        respx_mock.post("/v1/tools/screenshot").mock(return_value=httpx.Response(200, json={"foo": "bar"}))

        tool = await async_client.tools.with_raw_response.screenshot_webpage()

        assert tool.is_closed is True
        assert tool.http_request.headers.get("X-Stainless-Lang") == "python"
        assert await tool.json() == {"foo": "bar"}
        assert isinstance(tool, AsyncBinaryAPIResponse)

    @parametrize
    @pytest.mark.respx(base_url=base_url)
    async def test_streaming_response_screenshot_webpage(
        self, async_client: AsyncAnchorbrowser, respx_mock: MockRouter
    ) -> None:
        respx_mock.post("/v1/tools/screenshot").mock(return_value=httpx.Response(200, json={"foo": "bar"}))
        async with async_client.tools.with_streaming_response.screenshot_webpage() as tool:
            assert not tool.is_closed
            assert tool.http_request.headers.get("X-Stainless-Lang") == "python"

            assert await tool.json() == {"foo": "bar"}
            assert cast(Any, tool.is_closed) is True
            assert isinstance(tool, AsyncStreamedBinaryAPIResponse)

        assert cast(Any, tool.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["ProfileListResponse", "Data", "DataItem"]


class DataItem(BaseModel):
    created_at: Optional[datetime] = None
    """The timestamp when the profile was created."""

    description: Optional[str] = None
    """A description of the profile."""

    name: Optional[str] = None
    """The name of the profile."""

    session_id: Optional[str] = None
    """The browser session ID used to create this profile, if applicable."""

    source: Optional[Literal["session"]] = None
    """The source of the profile data."""

    status: Optional[str] = None
    """The current status of the profile."""


class Data(BaseModel):
    count: Optional[int] = None
    """Total number of profiles"""

    items: Optional[List[DataItem]] = None


class ProfileListResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["ClipboardSetParams"]


class ClipboardSetParams(TypedDict, total=False):
    text: Required[str]
    """Text to set in the clipboard"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .._models import BaseModel

__all__ = ["SessionListPagesResponse", "SessionListPagesResponseItem"]


class SessionListPagesResponseItem(BaseModel):
    id: str
    """The unique identifier of the page."""

    frontend_url: str
    """The frontend URL for accessing the page."""

    title: str
    """The title of the page."""

    url: str
    """The URL of the page."""


SessionListPagesResponse: TypeAlias = List[SessionListPagesResponseItem]
